/*
 * Copyright (c) 2002-2006 Samit Basu
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "Malloc.hpp"
#include "Exception.hpp"
#include <stdlib.h>
#include <stdio.h>

static int memoryBalance = 0;

void* Malloc(int count) {
  void* ptr;
  try {
    ptr = malloc(count);
    if (!ptr) throw Exception("Memory allocation error... You may have run out of memory!");
    memset(ptr,0,count);
    return ptr;
  } catch (...) {
    throw Exception("Memory allocation error... You may have run out of memory!");
  }
}

void Free(void *dp) {
  if (dp == NULL) return;
  free(dp);
}

void* Calloc(int count) {
  return Malloc(count);
}
